@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,15 +21,11 @@
 #define __DEFS_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
 
-#ifdef G_OS_WIN32
-#  include <glib/gwin32.h>
-#endif
-
 #if HAVE_PATHS_H
 #  include <paths.h>
 #endif
@@ -91,6 +87,7 @@
 #define TOOLS_URI		"http://www.claws-mail.org/tools.php"
 #define MAILING_LIST_URI	"http://www.claws-mail.org/MLs.php"
 #define USERS_ML_ADDR		"users@lists.claws-mail.org"
+#define USERS_ML_URI		"http://lists.claws-mail.org/cgi-bin/mailman/listinfo/users"
 #define GPL_URI			"http://www.gnu.org/licenses/gpl.html"
 #define DONATE_URI		"http://www.claws-mail.org/sponsors.php"
 #define RELEASE_NOTES_FILE	"RELEASE_NOTES"
@@ -115,6 +112,7 @@
 #  define ACTIONS_RC		"actionswinrc"
 #  define COMMAND_HISTORY	"command_history_win"
 #  define DEFAULT_SIGNATURE	"signature.txt"
+#  define DEFAULT_W32_GTK_THEME "MS-Windows"
 #else
 #  define ACTIONS_RC		"actionsrc"
 #  define COMMAND_HISTORY	"command_history"
@@ -148,6 +146,9 @@
 
 #define BUFFSIZE			8192
 
+/* according to RFC 821 1000 characters including CRLF */
+#define MAXSMTPTEXTLEN			1000
+
 #ifndef MAXPATHLEN
 #  define MAXPATHLEN			4095
 #endif
@@ -168,6 +169,15 @@
 #define PROGRESS_UPDATE_INTERVAL	200	/* msec */
 #define SESSION_TIMEOUT_INTERVAL	60	/* sec */
 #define MAX_HISTORY_SIZE		32
+#define HSPACING_NARROW			4
+#define VSPACING			10
+#define VSPACING_NARROW			4
+#define VSPACING_NARROW_2		2
+#define VBOX_BORDER			8
+#define DEFAULT_ENTRY_WIDTH		80
+/* labels bigger than this causes crash with the X Window System error:
+   'BadAlloc (insufficient resources for operation)' */
+#define MAX_MENU_LABEL_LENGTH		5453
 
 #define BOLD_FONT prefs_common.boldfont
 #define NORMAL_FONT prefs_common.normalfont
